cmrData.RdcmrData can be used to test social and movement network functions of CMRnet. It is an example of how dataframes should be organised to feed into CMRnet
data("cmrData")
A data frame with 1191 rows and 5 columns variables:
id - provides the identity of the individual captured
loc - the named capture location
x - geographic location of a capture event (on the horizontal axis)
y - geographic location of a capture event (on the vertical axis)
date - the capture date