cmrData2.RdA dataset that tests MultiMoveNetCreate. cmrData2 is an example of how dataframes should be created to feed into CMRnet when there are multiple layered movement networks (i.e. a separate network for males and females).
data("cmrData2")
A data frame with 1191 rows and 5 columns variables:
id - provides the identity of the individual captured
loc - the named capture location
x - geographic location of a capture event (on the horizontal axis)
y - geographic location of a capture event (on the vertical axis)
date - the capture date
layer - provides information used to define the layers of the multiplex network