cmrData3.RdcmrData3 to test DynamicNetCreateHi and MoveNetCreateHi. These functions help create short-term social and movement networks.cmrData3 is an example of how dataframes should be created to feed into CMRnet when capture times are relevant as well as capture dates.
data("cmrData3")
A data frame with 1191 rows and 5 columns variables:
id - provides the identity of the individual captured
loc - the named capture location
x - geographic location of a capture event (on the horizontal axis)
y - geographic location of a capture event (on the vertical axis)
date - the capture date in POSIXct format